Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1280)

Unified Diff: tools/SkBitmapRegionCanvas.h

Issue 1365313002: Merge SkCodec with SkScanlineDecoder (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Skip ICO in SkScaledCodec for now Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/CodexTest.cpp ('k') | tools/SkBitmapRegionCanvas.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/SkBitmapRegionCanvas.h
diff --git a/tools/SkBitmapRegionCanvas.h b/tools/SkBitmapRegionCanvas.h
index 96631d70d3333bf99ca5cf23e26d1415def92ab9..05eca8b3fcc3ab052c36ce1982c39136a6e8b570 100644
--- a/tools/SkBitmapRegionCanvas.h
+++ b/tools/SkBitmapRegionCanvas.h
@@ -7,10 +7,10 @@
#include "SkBitmap.h"
#include "SkBitmapRegionDecoderInterface.h"
-#include "SkScanlineDecoder.h"
+#include "SkCodec.h"
/*
* This class implements SkBitmapRegionDecoder using an SkScanlineDecoder and
* an SkCanvas. It uses the scanline decoder to subset the height. It then
* will subset the width and scale by drawing to an SkCanvas.
*/
@@ -22,7 +22,7 @@ public:
/*
* Takes ownership of pointer to decoder
*/
- SkBitmapRegionCanvas(SkScanlineDecoder* decoder);
+ SkBitmapRegionCanvas(SkCodec* decoder);
/*
* Three differences from the Android version:
@@ -36,7 +36,7 @@ public:
private:
- SkAutoTDelete<SkScanlineDecoder> fDecoder;
+ SkAutoTDelete<SkCodec> fDecoder;
typedef SkBitmapRegionDecoderInterface INHERITED;
« no previous file with comments | « tests/CodexTest.cpp ('k') | tools/SkBitmapRegionCanvas.cpp » ('j') | no next file with comments »
@@ -7,10 +7,10 @@
/*
- * This class implements SkBitmapRegionDecoder using an SkScanlineDecoder and
+ * This class implements SkBitmapRegionDecoder using an SkCodec and
* an SkCanvas. It uses the scanline decoder to subset the height. It then
* will subset the width and scale by drawing to an SkCanvas.

Powered by Google App Engine
This is Rietveld 408576698